shigoto_migration (shigoto v1.9.12)

Database migrations for Shigoto tables. Call up/1 with a minato pool name to create or update the jobs and cron tables.

Migrations are idempotent and safe to run multiple times.

Summary

Functions

Drop the shigoto tables.

Create or update the shigoto_jobs and shigoto_cron tables.

Functions

down(Pool)

-spec down(atom()) -> ok | {error, term()}.

Drop the shigoto tables.

up(Pool)

-spec up(atom()) -> ok | {error, term()}.

Create or update the shigoto_jobs and shigoto_cron tables.